@@ -493,7 +493,7 @@ class RestAPI(object):
 		for key, value in self.__plans__.items():
 			if plan_id == value["plan_id"]: 
 				return r3sponse.success_response("Successfully retrieved the plan.", {
-					"plan":value["plan_id"],
+					"plan":key,
 				})
 		return r3sponse.error_response(f"Failed to rerieve the plan name for stripe plan id [{plan_id}].")
 
